@@ -5,5 +5,5 @@ from .triple import Triple
 from .missing import Missing
 from .resource import Resource
 from .sentence import Sentence
-
-__all__ = ['AbstractNode', 'Triple', 'Missing', 'Resource', 'Sentence']
+from .list import List
+from .list_operators import Union, Intersection, And, Or, First, Last, Sort
